@@ -2,7 +2,7 @@
 import os
 
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 
 LIB_DIR = os.path.dirname(os.path.abspath(__file__))
@@ -17,7 +17,7 @@ MODEL_CONFIG_FILE = {
     'google_bert_base_zh': os.path.join(FILES_DIR, 'google_bert_base_zh.json'),
     'uer_bert_large_zh': os.path.join(FILES_DIR, 'uer_bert_large_zh.json'),
     'uer_bert_small_zh': os.path.join(FILES_DIR, 'uer_bert_small_zh.json'),
-    'uer_bert_tiny_zh': os.path.join(FILES_DIR, 'uer_bert_tiny_zh.json')
+    'uer_bert_tiny_zh': os.path.join(FILES_DIR, 'uer_bert_tiny_zh.json'),
 }
 
 
